<?php
/**
 * @copyright	Copyright (C) 2011 Simplify Your Web, Inc. All rights reserved.
 * @license		GNU General Public License version 3 or later; see LICENSE.txt
 */

defined( '_JEXEC' ) or die;

use Joomla\CMS\Component\ComponentHelper;
use Joomla\CMS\Form\FormHelper;
use Joomla\CMS\HTML\HTMLHelper;
use Joomla\CMS\Language\Text;

jimport('joomla.filesystem.folder');

FormHelper::loadFieldClass('list');

class JFormFieldFieldEdit extends \JFormFieldList
{
    public $type = 'FieldEdit';

    static $core_fields = null;

    static function getCoreFields()
    {
        if (!isset(self::$core_fields)) {
            \JLoader::register('FieldsHelper', JPATH_ADMINISTRATOR . '/components/com_fields/helpers/fields.php');
            self::$core_fields = FieldsHelper::getFields('com_weblinks.weblink');
        }

        return self::$core_fields;
    }

    protected function getOptions()
    {
        $options = array();

        //$options[] = HTMLHelper::_('select.option', 'empty', Text::_('COM_WEBLINKLOGOSPRO_VALUE_EMPTY'), 'value', 'text', $disable=false);
        $options[] = HTMLHelper::_('select.option', 'section', Text::_('COM_WEBLINKLOGOSPRO_VALUE_SECTION'), 'value', 'text', $disable=false);            

        // get Joomla! fields
        // test the fields folder first to avoid message warning that the component is missing
        if (\JFolder::exists(JPATH_ADMINISTRATOR . '/components/com_fields') && ComponentHelper::isEnabled('com_fields') && ComponentHelper::getParams('com_weblinks')->get('custom_fields_enable', '1')) {

            $fields = self::getCoreFields();

            // organize the fields according to their group

            $fieldsPerGroup = array(
                0 => array()
            );

            $groupTitles = array(
                0 => Text::_('COM_WEBLINKLOGOSPRO_VALUE_NOGROUPFIELD')
            );

            foreach ($fields as $field) {

                if (!array_key_exists($field->group_id, $fieldsPerGroup)) {
                    $fieldsPerGroup[$field->group_id] = array();
                    $groupTitles[$field->group_id] = $field->group_title;
                }

                $fieldsPerGroup[$field->group_id][] = $field;
            }

            // loop trough the groups

            foreach ($fieldsPerGroup as $group_id => $groupFields) {

                if (!$groupFields) {
                    continue;
                }

                $options[] = HTMLHelper::_('select.optgroup', $groupTitles[$group_id]);

                foreach ($groupFields as $field) {
                    if ($group_id == 0) {
                        $options[] = HTMLHelper::_('select.option', 'customfields_'.$field->name, $field->title, 'value', 'text', $disable = false);
                    } else {
                        $options[] = HTMLHelper::_('select.option', $field->id, $field->title, 'value', 'text', $disable = true);
                    }
                }

                $options[] = HTMLHelper::_('select.optgroup', $groupTitles[$group_id]);
            }
        }

        // Merge any additional options in the XML definition.
        $options = array_merge(parent::getOptions(), $options);

        return $options;
    }

}
?>
