<?php
/**
 * @copyright	Copyright (C) 2011 Simplify Your Web, Inc. All rights reserved.
 * @license		GNU General Public License version 3 or later; see LICENSE.txt
 */

// No direct access to this file
defined('_JEXEC') or die;

use Joomla\CMS\Factory;
use Joomla\CMS\Language\Text;
use Joomla\CMS\Component\ComponentHelper;
use Joomla\CMS\Installer\Installer;
use Joomla\CMS\Installer\InstallerHelper;

jimport('joomla.filesystem.file');
jimport('joomla.filesystem.folder');

/**
 * Script file of the Weblink Logos Pro component
 */
class com_weblinklogosproInstallerScript
{
	static $version = '4.7.3';
	static $minimum_needed_library_version = '1.6.17';
	static $available_languages = array('de-DE', 'en-GB', 'fa-IR', 'fr-FR', 'nl-NL', 'pl-PL', 'pt-BR', 'ru-RU', 'sl-SI', 'tr-TR');
	static $download_link = 'https://simplifyyourweb.com/downloads/syw-extension-library';
	static $weblinks_download_link = 'http://extensions.joomla.org/extensions/extension/official-extensions/weblinks';
	static $changelog_link = 'https://simplifyyourweb.com/downloads/weblink-logos-pro/file/366-weblink-logos-pro';

	/**
	 * method to run before an install/update method
	 *
	 * @return void
	 */
	function preflight($type, $parent)
	{
	    // make sure we are under Joomla 3.8 or over

	    if (version_compare(JVERSION, '3.8.0', 'lt')) {
	        Factory::getApplication()->enqueueMessage(Text::sprintf('JOOMLA_REQUIRED_VERSION', '3.8'), 'error');
	        return false;
	    }

	    if ($type == 'install' || $type == 'update') {

    		// check if Weblinks component is present

    		if (!\JFolder::exists(JPATH_ROOT.'/components/com_weblinks')) {

    			$message = Text::_('COM_WEBLINKLOGOSPRO_MISSING_WEBLINKSCOMPONENT').'.<br /><a href="'.self::$weblinks_download_link.'" target="_blank">'.Text::_('COM_WEBLINKLOGOSPRO_DOWNLOAD_WEBLINKSCOMPONENT').'</a>.';
    			Factory::getApplication()->enqueueMessage($message, 'error');
    			return false;
    		}

    		// check if syw library is present

    		if (!\JFolder::exists(JPATH_ROOT.'/libraries/syw')) {

    			if (!$this->installOrUpdatePackage($parent, 'lib_syw')) {
    				$message = Text::_('SYWLIBRARY_INSTALLFAILED').'<br /><a href="'.self::$download_link.'" target="_blank">'.Text::_('SYWLIBRARY_DOWNLOAD').'</a>';
    				Factory::getApplication()->enqueueMessage($message, 'error');
    				return false;
    			}

    			Factory::getApplication()->enqueueMessage(Text::sprintf('SYWLIBRARY_INSTALLED', self::$minimum_needed_library_version), 'message');

    		} else {
    		    jimport('syw.version', JPATH_LIBRARIES);

    			if (SYWVersion::isCompatible(self::$minimum_needed_library_version)) {

    				Factory::getApplication()->enqueueMessage(Text::_('SYWLIBRARY_COMPATIBLE'), 'message');

    			} else {

    				if (!$this->installOrUpdatePackage($parent, 'lib_syw')) {
    					$message = Text::_('SYWLIBRARY_UPDATEFAILED').'<br />'.Text::_('SYWLIBRARY_UPDATE');
    					Factory::getApplication()->enqueueMessage($message, 'error');
    					return false;
    				}

    				Factory::getApplication()->enqueueMessage(Text::sprintf('SYWLIBRARY_UPDATED', self::$minimum_needed_library_version), 'message');
    			}
    		}
	    }

		return true;
	}

	/**
	 * method to install the component
	 *
	 * @return void
	 */
	function install($parent) // $parent is the class calling this method
	{
		$manifest = $parent->get("manifest");
		$parent = $parent->getParent();
		$source = $parent->getPath("source");

		//$installer = new JInstaller();

		echo '<p style="margin: 10px 0 20px 0">';
		echo '<img src="../administrator/components/com_weblinklogospro/assets/images/logo.png" />';
		echo '<br /><br /><span class="label">'.Text::sprintf('COM_WEBLINKLOGOSPRO_VERSION', self::$version).'</span>';
		echo '<br /><br />Olivier Buisard @ <a href="https://simplifyyourweb.com" target="_blank">Simplify Your Web</a>';
		echo '</p>';

		echo '<div style="text-align: center">';

		// Install modules
		foreach($manifest->modules->module as $module) {
			$attributes = $module->attributes();

			$module_name = Text::_($attributes['name']);

			$mod = $source.'/'.$attributes['folder'].'/'.$attributes['module'];

			echo '<div style="display: inline-block; width: 300px; margin: 5px; text-align: center; vertical-align: top;">';

			$installer = new Installer();
			$success = $installer->install($mod);
			if ($success) {
				echo '<img src="../modules/'.$attributes['module'].'/images/logo.png" />';
				echo '<span class="alert alert-success" style="display: inline-block; margin: 15px 0px">'.Text::sprintf('COM_WEBLINKLOGOSPRO_INSTALLED', $module_name).'</span>';
			} else {
				echo '<span class="alert alert-warning" style="display: inline-block; margin: 15px 0px">'.Text::sprintf('COM_WEBLINKLOGOSPRO_ERRORINSTALLING', $module_name).'</span>';
			}

			echo '</div>';
		}

		// Install plugins
		foreach($manifest->plugins->plugin as $plugin) {
		    $attributes = $plugin->attributes();

			$plugin_name = Text::_($attributes['name']);

			$plg = $source.'/'.$attributes['folder'].'/'.$attributes['plugin'];

			$plugin_sans_plg = str_replace('plg_', '', $attributes['plugin']);
			$plugin_sans_plg = str_replace($attributes['group'].'_', '', $plugin_sans_plg);

			echo '<div style="display: inline-block; width: 300px; margin: 5px; text-align: center; vertical-align: top;">';

			$installer = new Installer();
			$success = $installer->install($plg);

			if ($success) {
			    echo '<img src="../plugins/'.$attributes['group'].'/'.$plugin_sans_plg.'/images/logo.png" />';
				echo '<span class="alert alert-success" style="display: inline-block; margin: 15px 0px">'.Text::sprintf('COM_WEBLINKLOGOSPRO_INSTALLED', $plugin_name).'</span>';
			} else {
				echo '<span class="alert alert-warning" style="display: inline-block; margin: 15px 0px">'.Text::sprintf('COM_WEBLINKLOGOSPRO_ERRORINSTALLING', $plugin_name).'</span>';
			}

			echo '</div>';
		}

		echo '</div>';
	}

	/**
	 * method to uninstall the component
	 *
	 * @return void
	 */
	function uninstall($parent)
	{
		$manifest = $parent->get("manifest");
		$parent = $parent->getParent();
		$source = $parent->getPath("source");
		$db = $parent->getDbo();

		// Uninstall modules
		foreach($manifest->modules->module as $module) {
			$attributes = $module->attributes();

			$module_name = Text::_($attributes['name']);

			$query = 'SELECT extension_id FROM #__extensions WHERE type=\'module\' AND element=\''.$attributes['module'].'\'';
			$db->setQuery($query);
			$moduleid = $db->loadResult();
			if ($moduleid) {
				$installer = new Installer();
				$success = $installer->uninstall('module', $moduleid);
				if ($success) {
					Factory::getApplication()->enqueueMessage(Text::sprintf('COM_WEBLINKLOGOSPRO_UNINSTALLED', $module_name), 'message');
				} else {
					Factory::getApplication()->enqueueMessage(Text::sprintf('COM_WEBLINKLOGOSPRO_ERRORUNINSTALLING', $module_name), 'error');
				}
			} else {
				Factory::getApplication()->enqueueMessage(Text::sprintf('COM_WEBLINKLOGOSPRO_COULDNOTFIND', $module_name), 'error');
			}
		}

		// Uninstall plugins
		foreach($manifest->plugins->plugin as $plugin) {
		    $attributes = $plugin->attributes();

			$plugin_name = Text::_($attributes['name']);

			$plugin_sans_plg = str_replace('plg_', '', $attributes['plugin']);
			$plugin_sans_plg = str_replace($attributes['group'].'_', '', $plugin_sans_plg);

			$query = 'SELECT extension_id FROM #__extensions WHERE type=\'plugin\' AND folder=\''.$attributes['group'].'\' AND element=\''.$plugin_sans_plg.'\'';
			$db->setQuery($query);
			$pluginid = $db->loadResult();
			if ($pluginid) {
				$installer = new Installer();
				$success = $installer->uninstall('plugin', $pluginid);
				if ($success) {
					Factory::getApplication()->enqueueMessage(Text::sprintf('COM_WEBLINKLOGOSPRO_UNINSTALLED', $plugin_name), 'message');
				} else {
					Factory::getApplication()->enqueueMessage(Text::sprintf('COM_WEBLINKLOGOSPRO_ERRORUNINSTALLING', $plugin_name), 'error');
				}
			} else {
				Factory::getApplication()->enqueueMessage(Text::sprintf('COM_WEBLINKLOGOSPRO_COULDNOTFIND', $plugin_name), 'error');
			}
		}
	}

	/**
	 * method to update the component
	 *
	 * @return void
	 */
	function update($parent)
	{
		$manifest = $parent->get("manifest");
		$parent = $parent->getParent();
		$source = $parent->getPath("source");

		//$installer = new JInstaller();

		echo '<p style="margin: 10px 0 20px 0">';
		echo '<img src="../administrator/components/com_weblinklogospro/assets/images/logo.png" />';
		echo '<br /><br /><span class="label">'.Text::sprintf('COM_WEBLINKLOGOSPRO_VERSION', self::$version).'</span>';
		echo '<br /><br />Olivier Buisard @ <a href="https://simplifyyourweb.com" target="_blank">Simplify Your Web</a>';
		echo '</p>';

		echo '<div style="text-align: center">';

		// Update modules
		foreach($manifest->modules->module as $module) {
			$attributes = $module->attributes();

			$module_name = Text::_($attributes['name']);

			$mod = $source.'/'.$attributes['folder'].'/'.$attributes['module'];

			echo '<div style="display: inline-block; width: 300px; margin: 5px; text-align: center; vertical-align: top;">';

			$path = JPATH_SITE.'/modules/'.$attributes['module'];
			if (\JFolder::exists($path)) {
				$installer = new Installer();
				$success = $installer->update($mod);
				if ($success) {
					echo '<img src="../modules/'.$attributes['module'].'/images/logo.png" />';
					echo '<span class="alert alert-success" style="display: inline-block; margin: 15px 0px">'.Text::sprintf('COM_WEBLINKLOGOSPRO_UPDATED', $module_name).'</span>';
				} else {
					echo '<span class="alert alert-warning" style="display: inline-block; margin: 15px 0px">'.Text::sprintf('COM_WEBLINKLOGOSPRO_ERRORUPDATING', $module_name).'</span>';
				}
			} else {
				$installer = new Installer();
				$success = $installer->install($mod);
				if ($success) {
					echo '<img src="../modules/'.$attributes['module'].'/images/logo.png" />';
					echo '<span class="alert alert-success" style="display: inline-block; margin: 15px 0px">'.Text::sprintf('COM_WEBLINKLOGOSPRO_INSTALLED', $module_name).'</span>';
				} else {
					echo '<span class="alert alert-warning" style="display: inline-block; margin: 15px 0px">'.Text::sprintf('COM_WEBLINKLOGOSPRO_ERRORINSTALLING', $module_name).'</span>';
				}
			}

			echo '</div>';
		}

		// Update plugins
		foreach($manifest->plugins->plugin as $plugin) {
		    $attributes = $plugin->attributes();

			$plugin_name = Text::_($attributes['name']);

			$plg = $source.'/'.$attributes['folder'].'/'.$attributes['plugin'];

			echo '<div style="display: inline-block; width: 300px; margin: 5px; text-align: center; vertical-align: top;">';

			$plugin_sans_plg = str_replace('plg_', '', $attributes['plugin']);
			$plugin_sans_plg = str_replace($attributes['group'].'_', '', $plugin_sans_plg);

			$path = JPATH_SITE.'/plugins/'.$attributes['group'].'/'.$plugin_sans_plg;
			if (\JFolder::exists($path)) {
				$installer = new Installer();
				$success = $installer->update($plg);
				if ($success) {
				    echo '<img src="../plugins/'.$attributes['group'].'/'.$plugin_sans_plg.'/images/logo.png" />';
					echo '<span class="alert alert-success" style="display: inline-block; margin: 15px 0px">'.Text::sprintf('COM_WEBLINKLOGOSPRO_UPDATED', $plugin_name).'</span>';
				} else {
					echo '<span class="alert alert-warning" style="display: inline-block; margin: 15px 0px">'.Text::sprintf('COM_WEBLINKLOGOSPRO_ERRORUPDATING', $plugin_name).'</span>';
				}
			} else {
				$installer = new Installer();
				$success = $installer->install($plg);
				if ($success) {
				    echo '<img src="../plugins/'.$attributes['group'].'/'.$plugin_sans_plg.'/images/logo.png" />';
					echo '<span class="alert alert-success" style="display: inline-block; margin: 15px 0px">'.Text::sprintf('COM_WEBLINKLOGOSPRO_INSTALLED', $plugin_name).'</span>';
				} else {
					echo '<span class="alert alert-warning" style="display: inline-block; margin: 15px 0px">'.Text::sprintf('COM_WEBLINKLOGOSPRO_ERRORINSTALLING', $plugin_name).'</span>';
				}
			}

			echo '</div>';
		}

		echo '</div>';
	}

	/**
	 * method to run after an install/update method
	 *
	 * @return void
	 */
	function postflight($type, $parent)
	{
	    if ($type == 'install' || $type == 'update') {

     		// language test

     		$current_language = Factory::getLanguage()->getTag();
     		if (!in_array($current_language, self::$available_languages)) {
     			Factory::getApplication()->enqueueMessage('The ' . Factory::getLanguage()->getName() . ' language is missing for this component.<br />Please consider contributing to its translation and get a license upgrade for your help!', 'notice');
     		}

     		// link to Quickstart

     		$message = Text::sprintf('COM_WEBLINKLOGOSPRO_INFO_LEARN', 'https://simplifyyourweb.com/documentation/weblink-logos/quickstart-guide');
     		$message .= '<br /><br /><a href="https://simplifyyourweb.com/documentation/weblink-logos/quickstart-guide" target="_blank"><img src="../modules/mod_weblinklogo/images/quickstart.png" /></a>';

     		Factory::getApplication()->enqueueMessage($message, 'notice');

     		// enable the installer plugin

     		$this->enableExtension('plugin', 'wlpinstaller', 'installer');

     		// move default place-holder to /images

     		$imagefiles = array();
     		$imagefiles[] = 'placeholder_camera.png';

     		$media_params = ComponentHelper::getParams('com_media');
     		$images_path = $media_params->get('image_path', 'images');

     		foreach ($imagefiles as $imagefile) {
     		    $src = JPATH_ROOT.'/modules/mod_weblinklogo/images/'.$imagefile;
     		    $dest = JPATH_ROOT.'/'.$images_path.'/'.$imagefile;

     		    if (!\JFile::copy($src, $dest)) {
     		        Factory::getApplication()->enqueueMessage(Text::sprintf('COM_WEBLINKLOGOSPRO_WARNING_COULDNOTCOPYFILE', $imagefile), 'warning');
     		    }
     		}

     		// remove the module and/or package update site of the free module

     		$this->removeUpdateSite('module', 'mod_weblinklogo');
     		$this->removeUpdateSite('package', 'pkg_weblinklogos', '', 'http://www.barejoomlatemplates.com/autoupdates/weblinklogos/weblinklogos-update.xml');
     		$this->removeUpdateSite('package', 'pkg_weblinklogos', '', 'http://www.barejoomlatemplates.com/autoupdates/weblinklogos/weblinklogos-pkg-update.xml');
     		$this->removeUpdateSite('package', 'pkg_weblinklogos', '', 'https://updates.simplifyyourweb.com/free/weblinklogos/weblinklogos-pkg-update.xml');

     		// remove the old update site

     		$this->removeUpdateSite('component', 'com_weblinklogospro', '', 'http://www.barejoomlatemplates.com/autoupdates/weblinklogospro/weblinklogospro-update.xml');
	    }

 		if ($type == 'install') {

			// enable the quickicon plugin

			//$this->enableExtension('plugin', 'weblinklogospro', 'quickicon');
 		}

		if ($type == 'update') {

			// update warning

		    Factory::getApplication()->enqueueMessage(Text::sprintf('COM_WEBLINKLOGOSPRO_WARNING_RELEASENOTES', self::$changelog_link), 'warning');

 			// delete unnecessary files

 			$files = array();

 			$files[] = '/modules/mod_weblinklogo/images/normal.png';
 			$files[] = '/modules/mod_weblinklogo/images/grow.png';
 			$files[] = '/modules/mod_weblinklogo/images/shrink.png';
 			$files[] = '/modules/mod_weblinklogo/images/preview.png';
 			$files[] = '/modules/mod_weblinklogo/stylemaster.css.php';
 			$files[] = '/modules/mod_weblinklogo/style.css.php';
 			$files[] = '/modules/mod_weblinklogo/styles/stylemaster.css.php';
 			$files[] = '/modules/mod_weblinklogo/fields/weblinkstest.php';
 			$files[] = '/modules/mod_weblinklogo/fields/extensionlinkwrapper.php';
 			$files[] = '/modules/mod_weblinklogo/fields/extensionlinkswrapper.php';
 			$files[] = '/modules/mod_weblinklogo/fields/messagewrapper.php';
 			$files[] = '/modules/mod_weblinklogo/fields/sywextensionpresencetestwrapper.php';

 			$files[] = '/components/com_weblinklogospro/assets/styles/directory/stylemaster.css.php';
 			$files[] = '/components/com_weblinklogospro/layouts/wlpcategoryindex.php';
 			$files[] = '/components/com_weblinklogospro/layouts/wlpicons.php';
 			$files[] = '/components/com_weblinklogospro/layouts/wlptagindex.php';

 			$files[] = '/administrator/components/com_weblinklogospro/models/fields/weblinkstest.php';
 			$files[] = '/administrator/components/com_weblinklogospro/views/info/view.json.php';

 			foreach ($files as $file) {
 				if (\JFile::exists(JPATH_ROOT.$file) && !\JFile::delete(JPATH_ROOT.$file)) {
 					Factory::getApplication()->enqueueMessage(Text::sprintf('COM_WEBLINKLOGOSPRO_ERROR_DELETINGFILEFOLDER', $file), 'warning');
 				}
 			}

 			// remove old cached headers which may interfere with fixes, updates or new additions

 			$filenames_to_delete = array();

 			if (function_exists('glob')) {

	 			// module

 				$filenames = glob(JPATH_SITE.'/cache/mod_weblinklogos/style_*.css');
	 			if ($filenames != false) {
	 				$filenames_to_delete = array_merge($filenames_to_delete, $filenames);
	 			}

	 			$filenames = glob(JPATH_SITE.'/cache/mod_weblinklogos/animation_*.js');
	 			if ($filenames != false) {
	 				$filenames_to_delete = array_merge($filenames_to_delete, $filenames);
	 			}

	 			// from previous versions

				$filenames = glob(JPATH_ROOT.'/modules/mod_weblinklogo/style_*.css');
				if ($filenames != false) {
					$filenames_to_delete = array_merge($filenames_to_delete, $filenames);
				}

				$filenames = glob(JPATH_ROOT.'/modules/mod_weblinklogo/styles/style_*.css');
				if ($filenames != false) {
					$filenames_to_delete = array_merge($filenames_to_delete, $filenames);
				}

				$filenames = glob(JPATH_ROOT.'/modules/mod_weblinklogo/animation_*.js');
				if ($filenames != false) {
					$filenames_to_delete = array_merge($filenames_to_delete, $filenames);
				}

	 			// views

				$filenames = glob(JPATH_SITE.'/cache/com_weblinklogospro/style_*.css');
				if ($filenames != false) {
					$filenames_to_delete = array_merge($filenames_to_delete, $filenames);
				}

				// from previous versions

	  			$filenames = glob(JPATH_ROOT.'/components/com_weblinklogospro/assets/styles/directory/style_*.css');
	  			if ($filenames != false) {
	  				$filenames_to_delete = array_merge($filenames_to_delete, $filenames);
	  			}
 			}

 			foreach ($filenames_to_delete as $filename) {
 				if (\JFile::exists($filename) && !\JFile::delete($filename)) {
 					Factory::getApplication()->enqueueMessage(Text::sprintf('COM_WEBLINKLOGOSPRO_ERROR_DELETINGFILEFOLDER', $filename), 'warning');
 				}
 			}

 			// get all directory views to fill the subforms (on the first update only)

 			$db = Factory::getDBO();

 			$query = $db->getQuery(true);

 			$query->select($db->quoteName('id'));
 			$query->select($db->quoteName('params'));
 			$query->from($db->quoteName('#__menu'));
 			$query->where('link LIKE '.$db->quote('%option=com_weblinklogospro&view=directory%'));

 			$db->setQuery($query);

 			$views = array();
 			try {
 				$views = $db->loadObjectList();
 			} catch (\RuntimeException $e) {
 				Factory::getApplication()->enqueueMessage(Text::_('JERROR_AN_ERROR_HAS_OCCURRED'), 'error');
 				return false;
 			}

 			foreach ($views as $view) {
 				$view_params = json_decode($view->params, true);

 				$changes_made = false;

 				// move form filters to subform
 				if (isset($view_params['top_pos_1'])) {

 					$filter_positions = array('top', 'bot');

 					foreach ($filter_positions as $index => $filter_position) {

 						$form_filters = array();

 						$j_sub = 0;

 						for ($j = 1; $j < 3; $j++) {
 							if (isset($view_params[$filter_position . '_pos_' . $j]) && $view_params[$filter_position . '_pos_' . $j] != 'none') {
 								$form_filter = array('formfilter' => $view_params[$filter_position . '_pos_' . $j]);
 								switch ($view_params[$filter_position . '_pos_' . $j]) {
 									case 'c' : $form_filter['ff_style'] = $view_params['cat_index_style']; $form_filter['ff_label'] = $view_params['cat_selection_label']; break;
 									case 't' : $form_filter['ff_style'] = $view_params['tag_index_style']; $form_filter['ff_label'] = $view_params['tag_selection_label'];
 								}
 								$form_filters[$filter_position . '_filters' . $j_sub] = $form_filter;
 								$j_sub++;
 							}
 						}

 						if (!empty($form_filters)) {
 							$view_params[$filter_position . '_filters'] = $form_filters;
 						}
 					}

 					// remove obsolete parameters

 					foreach ($filter_positions as $index => $filter_position) {
 						for ($j = 1; $j < 3; $j++) {
 							unset($view_params[$filter_position . '_pos_' . $j]);
 						}
 					}

 					unset($view_params['cat_index_style']);
 					unset($view_params['cat_selection_label']);
 					unset($view_params['tag_index_style']);
 					unset($view_params['tag_selection_label']);

 					$changes_made = true;
 				}

 				if ($changes_made) {

 					$query->clear();

 					$query->update('#__menu');
 					$query->set($db->quoteName('params').'='.$db->quote(json_encode($view_params)));
 					$query->where($db->quoteName('id').'='.$db->quote($view->id));

 					$db->setQuery($query);

 					try {
 						$db->query();
 					} catch (\RuntimeException $e) {
 						Factory::getApplication()->enqueueMessage(Text::_('JERROR_AN_ERROR_HAS_OCCURRED'), 'error');
 						return false;
 					}
 				}
 			}

 			// overrides warning

			$defaultemplate = $this->getDefaultTemplate();

			if ($defaultemplate) {
				$overrides_path = JPATH_ROOT.'/templates/'.$defaultemplate.'/html/';

				if (\JFolder::exists($overrides_path.'com_weblinklogospro') || \JFolder::exists($overrides_path.'mod_weblinklogo')) {
					Factory::getApplication()->enqueueMessage(Text::_('COM_WEBLINKLOGOSPRO_WARNING_OVERRIDES'), 'warning');
				}

	 			if (\JFolder::exists($overrides_path.'layouts/com_weblinklogospro')) {

	 			    if (count(\JFolder::files($overrides_path.'layouts/com_weblinklogospro', 'wlp[a-z]*.php')) > 0) {
	 			        Factory::getApplication()->enqueueMessage(Text::_('COM_WEBLINKLOGOSPRO_WARNING_LAYOUTOVERRIDES'), 'warning');
	 			        Factory::getApplication()->enqueueMessage(Text::_('Layout overrides have been moved to sub-folders. <a href="https://simplifyyourweb.com/documentation/weblink-logos/common-information/layouts" target="_blank">Check the documentation</a> for more information'), 'warning');
	 			    }

	 			    if (\JFolder::exists($overrides_path.'layouts/com_weblinklogospro/content') || \JFolder::exists($overrides_path.'layouts/com_weblinklogospro/pagination')) {
	 			        Factory::getApplication()->enqueueMessage(Text::_('COM_WEBLINKLOGOSPRO_WARNING_LAYOUTOVERRIDES'), 'warning');
	 			    }
	 			}
			}
		}

		return true;
	}

	private function enableExtension($type, $element, $folder = '', $enable = true)
	{
	    $db = Factory::getDBO();

	    $query = $db->getQuery(true);

	    $query->update($db->quoteName('#__extensions'));
	    if ($enable) {
	    	$query->set($db->quoteName('enabled').' = 1');
	    } else {
	    	$query->set($db->quoteName('enabled').' = 0');
	    }
	    $query->where($db->quoteName('type').' = '.$db->quote($type));
	    $query->where($db->quoteName('element').' = '.$db->quote($element));
	    if ($folder) {
	        $query->where($db->quoteName('folder').' = '.$db->quote($folder));
	    }

	    $db->setQuery($query);

	    try {
	        $db->execute();
	    } catch (\RuntimeException $e) {
	        Factory::getApplication()->enqueueMessage(Text::_('JERROR_AN_ERROR_HAS_OCCURRED'), 'error');
	        return false;
	    }

	    return true;
	}

	private function getDefaultTemplate()
	{
		$db = Factory::getDBO();

		$query = $db->getQuery(true);

		$query->select('template');
		$query->from('#__template_styles');
		$query->where($db->quoteName('client_id').'= 0');
		$query->where($db->quoteName('home').'= 1');

		$db->setQuery($query);

		$defaultemplate = '';

		try {
			$defaultemplate = $db->loadResult();
		} catch (\RuntimeException $e) {
			Factory::getApplication()->enqueueMessage(Text::_('JERROR_AN_ERROR_HAS_OCCURRED'), 'error');
		}

		return $defaultemplate;
	}

	private function removeUpdateSite($type, $element, $folder = '', $location = '')
	{
	    $db = Factory::getDBO();

	    $query = $db->getQuery(true);

	    $query->select('extension_id');
	    $query->from('#__extensions');
	    $query->where($db->quoteName('type').'='.$db->quote($type));
	    $query->where($db->quoteName('element').'='.$db->quote($element));
	    if ($folder) {
	        $query->where($db->quoteName('folder').'='.$db->quote($folder));
	    }

	    $db->setQuery($query);

	    $extension_id = '';
	    try {
	        $extension_id = $db->loadResult();
	    } catch (\RuntimeException $e) {
	        Factory::getApplication()->enqueueMessage(Text::_('JERROR_AN_ERROR_HAS_OCCURRED'), 'error');
	        return false;
	    }

	    if ($extension_id) {

	        $query->clear();

	        $query->select('update_site_id');
	        $query->from('#__update_sites_extensions');
	        $query->where($db->quoteName('extension_id').'='.$db->quote($extension_id));

	        $db->setQuery($query);

	        $updatesite_id = array(); // can have several results
	        try {
	            $updatesite_id = $db->loadColumn();
	        } catch (\RuntimeException $e) {
	            Factory::getApplication()->enqueueMessage(Text::_('JERROR_AN_ERROR_HAS_OCCURRED'), 'error');
	            return false;
	        }

	        if (empty($updatesite_id)) {
	            return false;
	        } else if (count($updatesite_id) == 1) {

	            $query->clear();

	            $query->delete($db->quoteName('#__update_sites'));
	            $query->where($db->quoteName('update_site_id').' = '.$db->quote($updatesite_id[0]));

	            $db->setQuery($query);

	            try {
	                $db->execute();
	            } catch (\RuntimeException $e) {
	                Factory::getApplication()->enqueueMessage(Text::_('JERROR_AN_ERROR_HAS_OCCURRED'), 'error');
	                return false;
	            }
	        } else { // several update sites exist for the same extension therefore we need to specify which to delete

	            if ($location) {
	                $query->clear();

	                $query->delete($db->quoteName('#__update_sites'));
	                $query->where($db->quoteName('update_site_id').' IN ('.implode(',', $updatesite_id).')');
	                $query->where($db->quoteName('location').' = '.$db->quote($location));

	                $db->setQuery($query);

	                try {
	                    $db->execute();
	                } catch (\RuntimeException $e) {
	                    Factory::getApplication()->enqueueMessage(Text::_('JERROR_AN_ERROR_HAS_OCCURRED'), 'error');
	                    return false;
	                }
	            } else {
	                return false;
	            }
	        }
	    } else {
	        return false;
	    }

	    return true;
	}

	private function installOrUpdatePackage($installer, $package_name, $installation_type = 'install')
	{
	    // Get the path to the package

	    $sourcePath = $installer->getParent()->getPath('source');
	    $sourcePackage = $sourcePath . '/packages/'.$package_name.'.zip';

	    // Extract and install the package

	    $package = InstallerHelper::unpack($sourcePackage);
	    if ($package === false || (is_array($package) && $package['type'] === false)) {
	        return false;
	    }

	    $tmpInstaller = new Installer();

	    if ($installation_type === 'install') {
	        return $tmpInstaller->install($package['dir']);
	    } else {
	        return $tmpInstaller->update($package['dir']);
	    }
	}

}
