<?php
/**
 * @copyright	Copyright (C) 2011 Simplify Your Web, Inc. All rights reserved.
 * @license		GNU General Public License version 3 or later; see LICENSE.txt
 */

defined('_JEXEC') or die;

use Joomla\CMS\Factory;
use Joomla\CMS\Language\Text;
use Joomla\CMS\Plugin\CMSPlugin;
use Joomla\CMS\Http\Http;

/**
 * WLPInstaller Plugin
 * for Joomla versions 3.2.3+
 */
class PlgInstallerWLPInstaller extends CMSPlugin
{
    protected $server_remote_uri = 'https://simplifyyourweb.com/autoupdates/';
    protected $extension = 'com_weblinklogospro';
    protected $autoloadLanguage = true;

    public function onInstallerBeforePackageDownload(&$url, &$headers)
    {
        // check that we update a SimplifyYourWeb pro extension
        if (preg_match('/weblinklogospro\//', $url) == false) {
            return false;
        }
        
        if (strpos($url, 'dlid=') !== false) { // bypass for third-party services
        	return true;
        }

        // fetch download id from extension parameters
        //JLoader::import('joomla.application.component.helper');
        //$downloadId = JComponentHelper::getParams($this->extension)->get('download_id', '');
        $downloadId = $this->params->get('download_id', '');

        //$valid = false;

        if ($downloadId) {

            // check if the download id is valid and the user license enabled here to provide better feedback to the user (other than 403 if download fails)

            $HTTPClient = new Http();

            $check_url = $this->server_remote_uri.'check.php?dlid='.$downloadId;

            try {
                $response = $HTTPClient->get($check_url)->body;
                if ($response) {
                    $status = json_decode($response, true);
                    if (empty($status)) {
                        Factory::getApplication()->enqueueMessage(Text::_('PLG_INSTALLER_WLPINSTALLER_MESSAGE_REMOTEDATABASEERROR'), 'warning');
                        //return false;
                    } else {
                        if ($status['enabled'] == 0) {
                            Factory::getApplication()->enqueueMessage(Text::_('PLG_INSTALLER_WLPINSTALLER_MESSAGE_DISABLEDLICENSE'), 'warning');
                            //return false;
                        } else {
                            if ($status['expiration_date']) {
                                $expiration_date = date(Text::_('DATE_FORMAT_LC3'), strtotime($status['expiration_date']));
                                if (strtotime('now') >= strtotime($status['expiration_date'])) {
                                    Factory::getApplication()->enqueueMessage(Text::sprintf('PLG_INSTALLER_WLPINSTALLER_MESSAGE_LICENSEEXPIRED', $expiration_date), 'warning');
                                    //return false;
                                } else {
                                    Factory::getApplication()->enqueueMessage(Text::sprintf('PLG_INSTALLER_WLPINSTALLER_MESSAGE_ACTIVELICENSE', $expiration_date), 'info');
                                    //$valid = true;
                                    if ((strtotime($status['expiration_date']) - strtotime('now')) < (60 * 60 * 24 * 120) ) {
                                        Factory::getApplication()->enqueueMessage(Text::sprintf('PLG_INSTALLER_WLPINSTALLER_MESSAGE_RENEWEARLY', '30'), 'info');
                                    }
                                }
                            } else {
                                Factory::getApplication()->enqueueMessage(Text::_('PLG_INSTALLER_WLPINSTALLER_MESSAGE_FOREVERACTIVELICENSE'), 'info');
                                //$valid = true;
                            }
                        }
                    }
                } else {
                    Factory::getApplication()->enqueueMessage(Text::_('PLG_INSTALLER_WLPINSTALLER_MESSAGE_REMOTESTATUSREQUESTFAILED'), 'error');
                    //return false;
                }
            } catch(\Exception $e) {
                Factory::getApplication()->enqueueMessage(Text::_('PLG_INSTALLER_WLPINSTALLER_MESSAGE_REMOTESTATUSREQUESTFAILED'), 'error');
                //return false;
            }
        } else {
            Factory::getApplication()->enqueueMessage(Text::_('PLG_INSTALLER_WLPINSTALLER_MESSAGE_MISSINGDOWNLOADID'), 'warning');
            //return false;
        }

        // bind credentials to request by appending it to the download url
        $separator = strpos($url, '?') !== false ? '&' : '?';
        $url .= $separator . 'dlid=' . $downloadId;

//         if ($valid) {
//             $url .= '&valid=1';
//         } else {
//             $url .= '&valid=0';
//         }

        return true;
    }
}
