<?php
/**
 * @copyright	Copyright (C) 2011 Simplify Your Web, Inc. All rights reserved.
 * @license		GNU General Public License version 3 or later; see LICENSE.txt
*/

// no direct access
defined('_JEXEC') or die;

use Joomla\CMS\Factory;
use Joomla\CMS\Http\Http;
use Joomla\CMS\Language\Text;
use Joomla\CMS\Plugin\CMSPlugin;

jimport('joomla.filesystem.file');
jimport('joomla.filesystem.folder');

class plgQuickiconWeblinklogospro extends CMSPlugin
{
    protected $autoloadLanguage = true;
    protected $_library_loaded = true;

    public function __construct(&$subject, $config)
    {
        parent::__construct($subject, $config);

        if (!\JFolder::exists(JPATH_LIBRARIES.'/syw')) {
            Factory::getApplication()->enqueueMessage(Text::_('PLG_QUICKICON_WEBLINKLOGOSPRO_WARNING_MISSINGLIBRARY'), 'error');
            $this->_library_loaded = false;
            return;
        }

        \JLoader::register('SYWLibraries', JPATH_LIBRARIES.'/syw/libraries.php');
        if (!class_exists('SYWLibraries')) {
            Factory::getApplication()->enqueueMessage(Text::_('PLG_QUICKICON_WEBLINKLOGOSPRO_WARNING_CORRUPTEDLIBRARY'), 'error');
            $this->_library_loaded = false;
        }
    }

	public function onGetIcons($context)
	{
	    if (!$this->_library_loaded) {
	        return;
	    }

		if ($context == $this->params->get('context', 'mod_quickicon') && Factory::getUser()->authorise('core.manage', 'com_weblinklogospro')) {

			//HTMLHelper::_('jquery.framework');

		    $HTTPClient = new Http();

			$url = 'https://updates.simplifyyourweb.com/pro/weblinklogospro/com_weblinklogospro.json';

			// Try to get informations
			try {
			    $latestVersion = '';

			    $response = $HTTPClient->get($url, null, 5)->body;
			    if($response) {
			        $decodedUpdateInfos = json_decode($response);
			        $latestVersion = $decodedUpdateInfos->{'latest'};
			        $infoVersion = $decodedUpdateInfos->{'relevance'};
			    }

			    if ($latestVersion) {
			    	SYWLibraries::loadCompareVersions();

					$currentVersion = strval(simplexml_load_file(JPATH_BASE . '/components/com_weblinklogospro/weblinklogospro.xml')->version);

//					$compareScript = 'jQuery(document).ready(function() { ';
//						$compareScript .= 'jQuery("span[data-bind=wlp_version]").html("'.$latestVersion.'"); ';
//						$compareScript .= 'SYWCompareVersions("'.$latestVersion.'","'.$currentVersion.'")?jQuery("span[data-status=wlp_uptodate]").show():jQuery("span[data-status=wlp_outdated]").show(); ';
//						$compareScript .= 'jQuery("span[data-status=wlp_unknown]").hide() ';
//					$compareScript .= ' }); ';

                    $compareScript = <<< JS
						document.addEventListener("readystatechange", function(event) {
							if (event.target.readyState === "complete") {
								document.querySelector("span[data-bind=wlp_version]").textContent = "{$latestVersion}";
								SYWCompareVersions("{$latestVersion}","{$currentVersion}") ? document.querySelector("span[data-status=wlp_uptodate]").style.display = "inline-block" : document.querySelector("span[data-status=wlp_outdated]").style.display = "inline-block";
								document.querySelector("span[data-status=wlp_unknown]").style.display = "none";
							}
						});
JS;

					$inlineCSS = <<< CSS
						.icon-wlp {
							background-image: url("../administrator/components/com_weblinklogospro/assets/images/weblinklogospro_16x16.png");
							width: 16px;
							height: 16px;
						}
CSS;

					Factory::getDocument()->addScriptDeclaration($compareScript);
					Factory::getDocument()->addStyleDeclaration($inlineCSS);

					return array(
						array(
							'link' => 'https://simplifyyourweb.com/downloads/weblink-logos-pro',
							'target' => '_blank',
							'image' => 'download',
							'text' => '<span data-status=\'wlp_unknown\'>'.Text::_('PLG_QUICKICON_WEBLINKLOGOSPRO_UNKNOWN_MESSAGE').'</span><span data-status=\'wlp_uptodate\' style=\'display:none\'>'.Text::_('PLG_QUICKICON_WEBLINKLOGOSPRO_VERSION_UPTODATE').'</span><span data-status=\'wlp_outdated\' style=\'display:none\'>'.Text::_('PLG_QUICKICON_WEBLINKLOGOSPRO_VERSION_OUTDATED').' <span title="' . htmlspecialchars($infoVersion, ENT_QUOTES, 'UTF-8') . '" class=\'hasTooltip label label-important\' data-bind=\'wlp_version\'></span></span>',
							'access' => array('core.manage', 'com_weblinklogospro'),
							'id' => 'plg_quickicon_weblinklogospro',
							'group' => 'MOD_QUICKICON_MAINTENANCE'
						),
						array(
							'link' => 'index.php?option=com_weblinklogospro',
							'image' => 'wlp',
							'text' => 'Weblink Logos Pro',
							'access' => array('core.manage', 'com_weblinklogospro'),
							'id' => 'plg_quickicon_weblinklogospro',
							'group' => 'MOD_QUICKICON_EXTENSIONS'
						)
					);
			    } else {
			        return;
			    }
			} catch(\Exception $e) {
			    return;
			}
		}
	}
}